==> qtjambi-webenginecore-6.6.0-sources.jar: io/qt/webengine/core/QWebEngineUrlSchemeHandler.java <==
package io.qt.webengine.core;

import io.qt.*;


/**
 * <p>Base class for handling custom URL schemes</p>
 * <p>Java wrapper for Qt class <code><a href="https://doc.qt.io/qt/qwebengineurlschemehandler.html">QWebEngineUrlSchemeHandler</a></code></p>
 */
public abstract class QWebEngineUrlSchemeHandler extends io.qt.core.QObject
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.@NonNull QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QWebEngineUrlSchemeHandler.class);
    
    @NativeAccess
    private static final class ConcreteWrapper extends QWebEngineUrlSchemeHandler {
        
        @NativeAccess
        private ConcreteWrapper(QPrivateConstructor p) { super(p); }
        
        @Override
        @QtUninvokable
        public void requestStarted(io.qt.webengine.core.@Nullable QWebEngineUrlRequestJob arg__1){
            requestStarted_native_QWebEngineUrlRequestJob_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(arg__1));
        }
        @QtUninvokable
        private native void requestStarted_native_QWebEngineUrlRequestJob_ptr(long __this__nativeId, long arg__1);
        
    }
    
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qwebengineurlschemehandler.html#QWebEngineUrlSchemeHandler">QWebEngineUrlSchemeHandler::<wbr>QWebEngineUrlSchemeHandler(QObject*)</a></code></p>
     */
    public QWebEngineUrlSchemeHandler(io.qt.core.@Nullable QObject parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QWebEngineUrlSchemeHandler instance, io.qt.core.QObject parent);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qwebengineurlschemehandler.html#requestStarted">QWebEngineUrlSchemeHandler::<wbr>requestStarted(QWebEngineUrlRequestJob*)</a></code></p>
     */
    @QtUninvokable
    public abstract void requestStarted(io.qt.webengine.core.@Nullable QWebEngineUrlRequestJob arg__1);
    
    @QtUninvokable
    private native void requestStarted_native_QWebEngineUrlRequestJob_ptr(long __this__nativeId, long arg__1);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected QWebEngineUrlSchemeHandler(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * @hidden
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @NativeAccess
    protected QWebEngineUrlSchemeHandler(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @QtUninvokable
    private static native void initialize_native(QWebEngineUrlSchemeHandler instance, QDeclarativeConstructor constructor);
    
    
    /**
     * <p>Overloaded constructor for {@link #QWebEngineUrlSchemeHandler(io.qt.core.QObject)}
     *  with <code>parent = null</code>.</p>
     */
    public QWebEngineUrlSchemeHandler() {
        this((io.qt.core.QObject)null);
    }
}

==> qtjambi-webenginecore-6.7.2-sources.jar: io/qt/webengine/core/QWebEngineUrlSchemeHandler.java <==
package io.qt.webengine.core;

import io.qt.*;


/**
 * <p>Base class for handling custom URL schemes</p>
 * <p>Java wrapper for Qt class <code><a href="https://doc.qt.io/qt/qwebengineurlschemehandler.html">QWebEngineUrlSchemeHandler</a></code></p>
 */
public abstract class QWebEngineUrlSchemeHandler extends io.qt.core.QObject
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.@NonNull QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QWebEngineUrlSchemeHandler.class);
    
    @NativeAccess
    private static final class ConcreteWrapper extends QWebEngineUrlSchemeHandler {
        
        @NativeAccess
        private ConcreteWrapper(QPrivateConstructor p) { super(p); }
        
        @Override
        @QtUninvokable
        public void requestStarted(io.qt.webengine.core.@Nullable QWebEngineUrlRequestJob arg__1){
            requestStarted_native_QWebEngineUrlRequestJob_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(arg__1));
        }
        @QtUninvokable
        private native void requestStarted_native_QWebEngineUrlRequestJob_ptr(long __this__nativeId, long arg__1);
        
    }
    
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qwebengineurlschemehandler.html#QWebEngineUrlSchemeHandler">QWebEngineUrlSchemeHandler::<wbr/>QWebEngineUrlSchemeHandler(QObject*)</a></code></p>
     */
    public QWebEngineUrlSchemeHandler(io.qt.core.@Nullable QObject parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QWebEngineUrlSchemeHandler instance, io.qt.core.QObject parent);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qwebengineurlschemehandler.html#requestStarted">QWebEngineUrlSchemeHandler::<wbr/>requestStarted(QWebEngineUrlRequestJob*)</a></code></p>
     */
    @QtUninvokable
    public abstract void requestStarted(io.qt.webengine.core.@Nullable QWebEngineUrlRequestJob arg__1);
    
    @QtUninvokable
    private native void requestStarted_native_QWebEngineUrlRequestJob_ptr(long __this__nativeId, long arg__1);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected QWebEngineUrlSchemeHandler(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     * @hidden
     */
    @NativeAccess
    protected QWebEngineUrlSchemeHandler(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @QtUninvokable
    private static native void initialize_native(QWebEngineUrlSchemeHandler instance, QDeclarativeConstructor constructor);
    
    
    /**
     * <p>Overloaded constructor for {@link #QWebEngineUrlSchemeHandler(io.qt.core.QObject)}
     *  with <code>parent = null</code>.</p>
     */
    public QWebEngineUrlSchemeHandler() {
        this((io.qt.core.QObject)null);
    }
}
